@@ -1,5 +1,6 @@
 class LineupOptimizerException(Exception):
     def __init__(self, message):
+        # type: (str) -> None
         self.message = message
 
     def __str__(self):
@@ -12,3 +13,8 @@ class LineupOptimizerIncorrectTeamName(LineupOptimizerException):
 
 class LineupOptimizerIncorrectPositionName(LineupOptimizerException):
     pass
+
+
+class LineupOptimizerIncorrectCSV(LineupOptimizerException):
+    def __init__(self, message='Incorrect csv format!'):
+        super(LineupOptimizerIncorrectCSV, self).__init__(message)
